#
# spec file for package perl-Mojo-SQLite
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Mojo-SQLite
Name:           perl-Mojo-SQLite
Version:        3.009
Release:        1.12
License:        Artistic-2.0
Summary:        Tiny Mojolicious wrapper for SQLite
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DB/DBOOK/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(DBD::SQLite) >= 1.68
BuildRequires:  perl(DBI) >= 1.627
BuildRequires:  perl(Module::Build::Tiny) >= 0.034
BuildRequires:  perl(Module::Metadata)
BuildRequires:  perl(Mojolicious) >= 8.03
BuildRequires:  perl(SQL::Abstract::Pg) >= 1.0
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(URI) >= 1.69
BuildRequires:  perl(URI::db) >= 0.15
BuildRequires:  perl(URI::file) >= 4.21
Requires:       perl(DBD::SQLite) >= 1.68
Requires:       perl(DBI) >= 1.627
Requires:       perl(Mojolicious) >= 8.03
Requires:       perl(SQL::Abstract::Pg) >= 1.0
Requires:       perl(URI) >= 1.69
Requires:       perl(URI::db) >= 0.15
Requires:       perl(URI::file) >= 4.21
%{perl_requires}

%description
Mojo::SQLite is a tiny wrapper around DBD::SQLite that makes at
https://www.sqlite.org/ a lot of fun to use with the at https://mojolico.us
real-time web framework. Use all at http://sqlite.org/lang.html SQLite has
to offer, generate CRUD queries from data structures, and manage your
database schema with migrations.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.md examples prereqs.yml README
%license LICENSE

%changelog
* Wed Mar 23 2022 Tina Müller <timueller+perl@suse.de>
- updated to 3.009
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  3.009     2022-03-22 20:16:03 EDT
  - Fix race condition in Mojo::SQLite::Migrations where two processes could attempt to create the same migration. (#25, Oliver Kurz)
* Mon Nov 29 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.008
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  3.008     2021-11-28 11:10:24 EST
  - Update documentation to indicate that upsert operations are now supported via SQL::Abstract::Pg.
* Mon Aug  2 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.007
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  3.007     2021-08-01 20:17:42 EDT
  - Increase DBD::SQLite dependency to 1.68 to support and use sqlite_string_mode over sqlite_unicode (#22, Adam Williamson)
  - The default options now set sqlite_string_mode to DBD_SQLITE_STRING_MODE_UNICODE_FALLBACK,
    unless sqlite_unicode is specified explicitly in from_string or from_filename. This is equivalent
    to the previous behavior but ensures that DBD::SQLite will not return malformed strings.
  - Support wal_mode option to enable WAL journaling mode, which is still currently the default,
    but may not be set by default in a future release.
* Thu Jun 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.006
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  3.006     2021-06-16 00:30:47 EDT
  - Set default abstract generator to an SQL::Abstract::Pg object, enabling additional features.
  - Update IRC metadata to libera.chat
* Wed Feb 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 3.005
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  3.005     2021-02-15 21:47:59 EST
  - Add query_p, select_p, insert_p, update_p, delete_p Mojo::Promise-returning methods to Mojo::SQLite::Database.
    These are for API compatibility with Mojo::Pg and do not provide non-blocking query functionality. (#20, Stefan Adams)
  - Use Mojo::Promise in tests instead of the deprecated and decored Mojo::IOLoop::Delay (#20, Stefan Adams)
* Tue Jul 28 2020 Tina Müller <timueller+perl@suse.de>
- updated to 3.004
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  3.004     2020-07-22 22:50:43 EDT
  - The Mojo::SQLite::Migrations sqlite attribute and the
    Mojo::SQLite::Transaction db attribute are now weak attributes, increasing
    the required version of Mojolicious to 8.03.
  - Defer loading of Mojo::IOLoop unless the callback compatibility API is
    used.
  - Newly created mojo_migrations tables from Mojo::SQLite::Migrations will use
    a primary key.
  - Recognize -json parameters in queries.
* Fri Oct  4 2019 <timueller+perl@suse.de>
- updated to 3.003
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  3.003     2019-10-01 15:49:43 EDT
  - Increase DBD::SQLite dependency to 1.64 to support configuring
    double-quoted string literals.
  - Disable double-quoted string literals for all connections.
    https://www.sqlite.org/quirks.html#double_quoted_string_literals_are_accepted
  - Change default SQL::Abstract identifier back to double quote.
* Sat Jun 22 2019 Stephan Kulow <coolo@please-enter-an-email-address>
- updated to 3.002
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  3.002     2019-06-21 17:41:35 EDT
  - Changed default SQL::Abstract identifier quoting character to `, as double
    quoted identifiers may be interpreted as string literals if they are not
    valid identifiers. https://www.sqlite.org/quirks.html#double_quoted_string_literals_are_accepted
* Sun Jul 22 2018 coolo@suse.com
- updated to 3.001
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
* Fri Jul 21 2017 coolo@suse.com
- updated to 3.000
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  3.000     2017-07-20 01:16:50 EDT
  - Changed default for max_connections attribute to 1.
  - Added support for sharing the database connection cache between multiple
    Mojo::SQLite objects. (based on Mojo::Pg 4.0)
  - Added parent attribute to Mojo::SQLite.
  - Fixed database connection leak with automatic migrations.
  - Removed deprecated Mojo::SQLite::PubSub and associated methods and attributes.
    SQLite's serverless nature means it does not have the ability to support
    client notifications, so it is not possible to implement an efficient
    pubsub system as in for example PostgreSQL, Redis, or websockets.
* Fri Jun  2 2017 coolo@suse.com
- updated to 2.002
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  2.002     2017-06-01 14:16:34 EDT
  - Add no_wal option to prevent enabling WAL mode on connection.
* Sun Feb 19 2017 coolo@suse.com
- updated to 2.001
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  2.001     2017-02-18 15:36:16 EST
  - Set name_sep in default SQL::Abstract object to support proper quoting of
    table and column names.
* Sun Feb 12 2017 coolo@suse.com
- updated to 2.000
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  2.000     2017-02-11 17:03:53 EST
  - Add support for generating queries with SQL::Abstract. (based on Mojo::Pg 3.0)
  - Add abstract attribute to Mojo::SQLite.
  - Add delete, insert, select, and update methods to Mojo::SQLite::Database.
* Wed Jan 18 2017 coolo@suse.com
- updated to 1.004
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  1.004     2017-01-17 00:10:51 EST
  - Use Mojo::File from Mojolicious 7.15 instead of deprecated
    Mojo::Util slurp function. (#9)
* Mon Dec 12 2016 coolo@suse.com
- updated to 1.003
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  1.003     2016-12-11 16:30:31 EST
  - Add links to alternatives for deprecated Mojo::SQLite::PubSub.
* Thu Dec  1 2016 coolo@suse.com
- updated to 1.002
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  1.002     2016-11-30 11:17:56 EST
  - Improved contextual caller information in query error messages. (#6)
  - Fix memory leak when reusing the same database handle many times. (#7)
* Wed Nov 16 2016 coolo@suse.com
- updated to 1.001
  see /usr/share/doc/packages/perl-Mojo-SQLite/Changes
  1.001     2016-11-15 02:32:27 EST
  - Deprecate Mojo::SQLite::PubSub and associated methods and attributes.
    SQLite's serverless nature means it does not have the ability to support
    client notifications, so it is not possible to implement an efficient
    pubsub system as in for example PostgreSQL, Redis, or websockets.
* Mon Nov  7 2016 sriedel@suse.de
- initial version (1.000)
